@@ -22,9 +22,7 @@
 #' @param parms \code{\linkS4class{RLum.Results}} (\bold{required}): The specific model parameters are used to simulate
 #' numerical quartz luminescence results.
 #'
-#' @return This function returns an Rlum.Results object from the LM-OSL simulation.
-#'
-#' @note This function can do just nothing at the moment.
+#' @return This function returns an RLum.Results object from the LM-OSL simulation.
 #'
 #' @section Function version: 0.1.1
 #'
@@ -107,12 +105,19 @@
   ##============================================================================##
 
   times <- seq(from = 0, to = duration, by = 0.1)
-  parameters.step  <- list(R = R, P = P, temp = temp, b = b, a = a, times = times, parms = parms)
-
+  parameters.step <- .extract_pars(parameters.step = list(
+    a = a,
+    R = R,
+    P = P,
+    temp = temp,
+    b = b,
+    times = times,
+    parms = parms))
+  
   ##============================================================================##
   # SOLVING ODE (deSolve requiered)
   ##============================================================================##
-  out <- deSolve::ode(y = n, times = times, parms = parameters.step, func = .set_ODE, rtol=1e-3, atol=1e-3, maxsteps=1e5, method = "bdf");
+  out <- deSolve::ode(y = n, times = times, parms = parameters.step, func = .set_ODE_Rcpp, rtol=1e-3, atol=1e-3, maxsteps=1e5, method = "bdf")
   ##============================================================================##
 
   ##============================================================================##
@@ -145,7 +150,9 @@
                       data = matrix(data = c(times[2:length(times)], signal[2:length(signal)]),ncol = 2),
                       recordType = "LM-OSL",
                       curveType = "simulated",
-                      info = list(RLumModel_ID = RLumModel_ID)
+                      info = list(
+                        curveDescripter = NA_character_),
+                      .pid = as.character(RLumModel_ID)
                       ),
                     temp = temp,
                     concentrations = concentrations)
